@@ -1,4 +1,3 @@
-import json
 import requests
 from bs4 import BeautifulSoup
 
@@ -6,10 +5,8 @@ from bs4 import BeautifulSoup
 #This programe is create by Sujit Mandal
 """
 Github: https://github.com/sujitmandal
-This programe is create by Sujit Mandal
+Pypi : https://pypi.org/user/sujitmandal/
 LinkedIn : https://www.linkedin.com/in/sujit-mandal-91215013a/
-Facebook : https://www.facebook.com/sujit.mandal.33671748
-Twitter : https://twitter.com/mandalsujit37
 """
 
 #search on google "my user agent"
@@ -28,7 +25,7 @@ def Google(search, userAgent):
         soup = BeautifulSoup(request.content, 'html.parser')
         results = []
     
-        for i in soup.find_all('div', {'class' : 'r'}):
+        for i in soup.find_all('div', {'class' : 'yuRUbf'}):
             link = i.find_all('a')
             links = link[0]['href']
             results.append(links)
@@ -96,77 +93,22 @@ def Bing(search, userAgent):
 
 def Yahoo(search, userAgent):
     URL = ('https://search.yahoo.com/search?q=' + search)
-    headers = {'user-agent' : userAgent}
-    request = requests.get(URL, headers=headers)
+    request = requests.get(URL)
 
     if request.status_code == 200:
         soup = BeautifulSoup(request.content, 'html.parser')
         results = []
     
-        for i in soup.find_all('div', {'class' : 'compTitle options-toggle'}):
-            link = i.find_all('a')
-            links = link[0]['href']
-            results.append(links)
+        for i in soup.find_all(attrs={"class": "ac-algo fz-l ac-21th lh-24"}):
+            link = i.get('href')
+            results.append(link)
 
     return(results)
 
-def CommonLinks(search, userAgent):
-    googleSearch = Google(search, userAgent)
-    duckduckgoSearch = Duckduckgo(search, userAgent)
-    givewaterSearch = Givewater(search, userAgent)
-    ecosiaSearch = Ecosia(search, userAgent)
-    bingSearch = Bing(search, userAgent)
-
-    googleSet = set(googleSearch)
-    duckduckgoSet = set(duckduckgoSearch)
-    givewaterSet = set(givewaterSearch)
-    ecosiaSet = set(ecosiaSearch)
-    bingSet = set(bingSearch)
-
-    intersection1 = googleSet.intersection(givewaterSet)
-    intersection2 = intersection1.intersection(duckduckgoSet)
-    intersection3 = intersection2.intersection(ecosiaSet)
-    intersection4 = intersection3.intersection(bingSet)
- 
-    intersectionList = list(intersection4)
-    finalList = []
-
-    for i in intersectionList:
-        finalList.append(i)
-
-    finalList.sort()
-    keys = []
-    for i in range(len(finalList)):
-        key = i + 1
-        keys.append(key)
-
-    commonDictionary = {}
-    commonDictionary['CommonLinks'] = dict(zip(keys, finalList))
-    return(commonDictionary)
-
-def makeJson(name, searchEngine):
-    keys = []
-
-    for i in range(len(searchEngine)):
-        key = i + 1
-        keys.append(key)
-
-    Dictionary = {}
-    Dictionary[name] = dict(zip(keys, searchEngine))
-
-    with open(name + '.json', 'w') as j:
-        json.dump(Dictionary, j)
-    print(name + ' File Saved')
-    return(Dictionary)
-
-
-
 if __name__ == "__main__":
     Bing(search, userAgent)
     Yahoo(search, userAgent)
     Google(search, userAgent)
     Ecosia(search, userAgent)
     Givewater(search, userAgent)
-    Duckduckgo(search, userAgent)
-    CommonLinks(search, userAgent)
-    makeJson(name, searchEngine)
\ No newline at end of file
+    Duckduckgo(search, userAgent)
\ No newline at end of file
